Coverage for src/paperap/tests/__init__.py: 100%

1"""

2

3

4

5 ----------------------------------------------------------------------------

6

7 METADATA:

8

9 File: __init__.py

10 Project: paperap

11 Created: 2025-03-04

12 Version: 0.0.6

13 Author: Jess Mann

14 Email: jess@jmann.me

15 Copyright (c) 2025 Jess Mann

16

17 ----------------------------------------------------------------------------

18

19 LAST MODIFIED:

20

21 2025-03-04 By Jess Mann

22

23"""

24 from paperap.tests.utils import load_sample_data, defaults, random_string, random_json, create_client, create_resource

25 from paperap.tests.testcase import TestMixin

26 from paperap.tests.unittest import (CorrespondentUnitTest, CustomFieldUnitTest, DocumentUnitTest,

27 DocumentTypeUnitTest, GroupUnitTest, ProfileUnitTest,

28 SavedViewUnitTest, ShareLinksUnitTest,

29 StoragePathUnitTest, TagUnitTest, TaskUnitTest,

30 UnitTestCase, UISettingsUnitTest, UserUnitTest,

31 WorkflowActionUnitTest, WorkflowUnitTest,

32 WorkflowTriggerUnitTest)

33 from paperap.tests.pytest import (CorrespondentPyTest, CustomFieldPyTest, DocumentPyTest,

34 DocumentTypePyTest, GroupPyTest, ProfilePyTest,

35 SavedViewPyTest, ShareLinksPyTest,

36 StoragePathPyTest, TagPyTest, TaskPyTest,

37 PyTestCase, UISettingsPyTest, UserPyTest,

38 WorkflowActionPyTest, WorkflowPyTest,

39 WorkflowTriggerPyTest)